==> pipewire-docs-1%3A0.3.59-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__context.js <==
var group__pw__context =
[
    [ "context.h", "context_8h.html", null ],
    [ "pw_context_events", "structpw__context__events.html", [
      [ "version", "structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c", null ],
      [ "destroy", "structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e", null ],
      [ "free", "structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87", null ],
      [ "check_access", "structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c", null ],
      [ "global_added", "structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d", null ],
      [ "global_removed", "structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0", null ]
    ] ],
    [ "pw_export_type", "structpw__export__type.html", [
      [ "link", "structpw__export__type.html#a753c33021857c67d7bd9df56ebd13116", null ],
      [ "type", "structpw__export__type.html#a2a49749c0d81fc22b2d70845a5c04e3b", null ],
      [ "func", "structpw__export__type.html#a2697ec1513e5a9fd156bfd41a1c26d6a", null ]
    ] ],
    [ "pw_context", "structpw__context.html", null ],
    [ "pw_global", "structpw__global.html", null ],
    [ "pw_impl_client", "structpw__impl__client.html", null ],
    [ "PW_VERSION_CONTEXT_EVENTS", "group__pw__context.html#ga1cb169be36ad0e32410951c8ff535743", null ],
    [ "pw_context_new", "group__pw__context.html#gab40dbe45a3b8282f99c4d27863411e5f", null ],
    [ "pw_context_destroy", "group__pw__context.html#ga41fdab6368603144f0911541182713a1", null ],
    [ "pw_context_get_user_data", "group__pw__context.html#ga00b5fe35e858f993eacc29fed285f377", null ],
    [ "pw_context_add_listener", "group__pw__context.html#ga44d2d1b5d618438873016c764584f1e5", null ],
    [ "pw_context_get_properties", "group__pw__context.html#ga87b444d4781c05318b30cf1931043ae4", null ],
    [ "pw_context_update_properties", "group__pw__context.html#ga48011f6ba07333a33f880778da4a1c86", null ],
    [ "pw_context_get_conf_section", "group__pw__context.html#ga44f13e3b82c3410300156b243889b803", null ],
    [ "pw_context_parse_conf_section", "group__pw__context.html#gaf3087e8f7ab10df538d6d1537bb19dfc", null ],
    [ "pw_context_conf_update_props", "group__pw__context.html#ga7bf88ef28e2758d787aed8acc71fce1f", null ],
    [ "pw_context_conf_section_for_each", "group__pw__context.html#ga528a327a97baf293d4765d0085719b91", null ],
    [ "pw_context_conf_section_match_rules", "group__pw__context.html#ga757bd6600757778772508ec97eefd7e6", null ],
    [ "pw_context_get_support", "group__pw__context.html#gad73656626f5f88f5ace1569b11073b22", null ],
    [ "pw_context_get_main_loop", "group__pw__context.html#gab3832ce0cf064dea0ba7f502a16a55aa", null ],
    [ "pw_context_get_data_loop", "group__pw__context.html#gaac1368cbbe2e1a00b066c552c86ba3a8", null ],
    [ "pw_context_get_work_queue", "group__pw__context.html#gad466760a74623341ac33d267581ddf39", null ],
    [ "pw_context_for_each_global", "group__pw__context.html#gaaa07217fcfeba4dd0a0269ff313a75d7", null ],
    [ "pw_context_find_global", "group__pw__context.html#gae01b3e37bd9c02da61ac4bad64dc7217", null ],
    [ "pw_context_add_spa_lib", "group__pw__context.html#gace5ee0a357a22a1dd86e3398956a621e", null ],
    [ "pw_context_find_spa_lib", "group__pw__context.html#ga8970b7ecc709a445142eec2742ac4f3a", null ],
    [ "pw_context_load_spa_handle", "group__pw__context.html#ga0a44b5fcb071f0e82004b929af3d1a90", null ],
    [ "pw_context_register_export_type", "group__pw__context.html#ga39a9e29ddc0cad4ced7d6034a64e3aff", null ],
    [ "pw_context_find_export_type", "group__pw__context.html#ga718d8f124cf5f06c0f21b15a0b34e0db", null ],
    [ "pw_context_set_object", "group__pw__context.html#ga1e67973ea8236ff8bc6125a437b79a76", null ],
    [ "pw_context_get_object", "group__pw__context.html#ga5455f68cb23daa8557d884ad342b518d", null ]
];

==> pipewire-docs-1%3A0.3.76-2-armv7h.pkg.tar.xz: usr/share/doc/pipewire/html/group__pw__context.js <==
var group__pw__context =
[
    [ "src/pipewire/context.h", "src_2pipewire_2context_8h.html", null ],
    [ "pw_context_events", "structpw__context__events.html", [
      [ "version", "structpw__context__events.html#ad0a1b4e42b11a408175ab4f70b1bbc7c", null ],
      [ "destroy", "structpw__context__events.html#a34b60636aee5925696ca80cbbf63755e", null ],
      [ "free", "structpw__context__events.html#a9c874d491dfbdd13eb81c7b0b7561e87", null ],
      [ "check_access", "structpw__context__events.html#af3303a7f003c10bfbb454c0bbd13360c", null ],
      [ "global_added", "structpw__context__events.html#a15e3c312ad2339ed431059d76fea5a4d", null ],
      [ "global_removed", "structpw__context__events.html#a8b2b69a9c179e37c9185929535a047f0", null ],
      [ "driver_added", "structpw__context__events.html#af555de72a4d29b3d7c5074aa5e7ab6b0", null ],
      [ "driver_removed", "structpw__context__events.html#a7ff739c9ebd412efa10756ececc1a27c", null ]
    ] ],
    [ "pw_export_type", "structpw__export__type.html", [
      [ "link", "structpw__export__type.html#a753c33021857c67d7bd9df56ebd13116", null ],
      [ "type", "structpw__export__type.html#a2a49749c0d81fc22b2d70845a5c04e3b", null ],
      [ "func", "structpw__export__type.html#a2697ec1513e5a9fd156bfd41a1c26d6a", null ]
    ] ],
    [ "pw_context", "structpw__context.html", null ],
    [ "pw_global", "structpw__global.html", null ],
    [ "pw_impl_client", "structpw__impl__client.html", null ],
    [ "pw_impl_node", "structpw__impl__node.html", null ],
    [ "PW_VERSION_CONTEXT_EVENTS", "group__pw__context.html#ga1cb169be36ad0e32410951c8ff535743", null ],
    [ "pw_context_new", "group__pw__context.html#gab40dbe45a3b8282f99c4d27863411e5f", null ],
    [ "pw_context_destroy", "group__pw__context.html#ga41fdab6368603144f0911541182713a1", null ],
    [ "pw_context_get_user_data", "group__pw__context.html#ga00b5fe35e858f993eacc29fed285f377", null ],
    [ "pw_context_add_listener", "group__pw__context.html#ga44d2d1b5d618438873016c764584f1e5", null ],
    [ "pw_context_get_properties", "group__pw__context.html#ga87b444d4781c05318b30cf1931043ae4", null ],
    [ "pw_context_update_properties", "group__pw__context.html#ga48011f6ba07333a33f880778da4a1c86", null ],
    [ "pw_context_get_conf_section", "group__pw__context.html#ga44f13e3b82c3410300156b243889b803", null ],
    [ "pw_context_parse_conf_section", "group__pw__context.html#gaf3087e8f7ab10df538d6d1537bb19dfc", null ],
    [ "pw_context_conf_update_props", "group__pw__context.html#ga7bf88ef28e2758d787aed8acc71fce1f", null ],
    [ "pw_context_conf_section_for_each", "group__pw__context.html#ga528a327a97baf293d4765d0085719b91", null ],
    [ "pw_context_conf_section_match_rules", "group__pw__context.html#ga757bd6600757778772508ec97eefd7e6", null ],
    [ "pw_context_get_support", "group__pw__context.html#gad73656626f5f88f5ace1569b11073b22", null ],
    [ "pw_context_get_main_loop", "group__pw__context.html#gab3832ce0cf064dea0ba7f502a16a55aa", null ],
    [ "pw_context_get_data_loop", "group__pw__context.html#gaac1368cbbe2e1a00b066c552c86ba3a8", null ],
    [ "pw_context_get_work_queue", "group__pw__context.html#gad466760a74623341ac33d267581ddf39", null ],
    [ "pw_context_get_mempool", "group__pw__context.html#ga9c835acd109e29efabe1fd544d28e0b8", null ],
    [ "pw_context_for_each_global", "group__pw__context.html#gaaa07217fcfeba4dd0a0269ff313a75d7", null ],
    [ "pw_context_find_global", "group__pw__context.html#gae01b3e37bd9c02da61ac4bad64dc7217", null ],
    [ "pw_context_add_spa_lib", "group__pw__context.html#gace5ee0a357a22a1dd86e3398956a621e", null ],
    [ "pw_context_find_spa_lib", "group__pw__context.html#ga8970b7ecc709a445142eec2742ac4f3a", null ],
    [ "pw_context_load_spa_handle", "group__pw__context.html#ga0a44b5fcb071f0e82004b929af3d1a90", null ],
    [ "pw_context_register_export_type", "group__pw__context.html#ga39a9e29ddc0cad4ced7d6034a64e3aff", null ],
    [ "pw_context_find_export_type", "group__pw__context.html#ga718d8f124cf5f06c0f21b15a0b34e0db", null ],
    [ "pw_context_set_object", "group__pw__context.html#ga1e67973ea8236ff8bc6125a437b79a76", null ],
    [ "pw_context_get_object", "group__pw__context.html#ga5455f68cb23daa8557d884ad342b518d", null ]
];
